using System;
using System.Drawing;


namespace PlayWithFriends
{
	/// <summary>
	/// Holds all the settings for the game in a single place. Also holds some useful
	/// constants used throughout the game.
	/// </summary>
	public class Settings
	{
		/// <summary>
		/// root of all the resource access. Makes it easier to move the program
		/// into different projects/namespaces
		/// </summary>
		public const string ImageResourceLoc = "PlayWithFriends.images.";

		/// <summary>
		/// root of all the sound resource access.
		/// </summary>
        public const string SoundResourceLoc = "PlayWithFriends.sounds.";

		/// <summary>
		/// name of file holding background image. If this is an empty string the
		/// program will use a solid black image
		/// </summary>
		public const string BackgroundImageFilename = "background.jpg";

		/// <summary>
		/// Background color for the playfield if an image is not used.
		/// </summary>
		public static readonly Color BackgroundColor = Color.Black;

		/// <summary>
		/// number of background stars on the playfield
		/// </summary>
		public const int NoOfBackgroundStars = 10;

		/// <summary>
		/// Number of coloured background stars on the playfield
		/// </summary>
		public const int NoOfColoredBackgroundStars = 5;

		/// <summary>
		/// File containing the ship animation panes
		/// </summary>
		public const string ShipImageFilename = "ship.png";

		/// <summary>
		/// File containing the explosion animation panes
		/// </summary>
		public const string ExplosionImageFilename = "explosion.png";

		public static readonly Color TransparentColor = Color.FromArgb ( 254, 0, 254 ) ;

		public static readonly System.Drawing.Imaging.ImageAttributes TransparentAttributes ;

		/// <summary>
		/// Sound played when a craft is damaged
		/// </summary>
		public const string DamageSound = "damaged.wav";

		/// <summary>
		/// Sound played when a craft is destroyed
		/// </summary>
		public const string DestroyedSound = "destroyed.wav";

		/// <summary>
		/// Sound played when a shot is fired
		/// </summary>
		public const string ShotSound = "shot.wav";

		/// <summary>
		/// Initialiser for the class. Sets the things which cannot be hard coded
		/// </summary>
		static Settings () 
		{ 
			TransparentAttributes = new System.Drawing.Imaging.ImageAttributes();
			TransparentAttributes.SetColorKey ( TransparentColor, TransparentColor ) ;
		}


		
	}
}
